
# 目录说明
Csvs csv文件部分  
Codes 代码部分  

# 使用方法

## 配置
Settings 是配置目录，主要是用文件夹分项目，定义各类文件名(注意 / 区分目录层级)  
ModelConfig 是模型参数文件，目前尽量收录了建模需要的参数，在此统一修改  
ReportConfig 是报表参数文件，定义模型参数文件位置和图表格式  

## 运行
使用 StartProject.py 文件启动项目，请查看文件中对应的注释使用
